.. _image_models:

******************************************
Morphology models (`gammapy.image.models`)
******************************************

.. currentmodule:: gammapy.image.models

Introduction
============

`gammapy.image.models` contains implementations of common 2-dimensional spatial
models.

Getting Started
===============

TODO: write me

Reference/API
=============

.. automodapi:: gammapy.image.models
    :no-inheritance-diagram:
